@@ -1,11 +1,19 @@
-from .dictionaries import DictObject, apply_dict_object, DictionaryView
+from .dictionaries import DictObject, apply_dict_object, DictionaryView, TwoWayDictionary
 from .hashable_objects import HashableWrapper
 from .immutable import Immutable, frozendict
 from .singleton import Singleton, SingletonWithRegardsTo
 from .structures import SetHeap, OmniHashableMixin, TimeBasedHeap, Heap
+from .proxy import Proxy
 from .typednamedtuple import typednamedtuple
+from .ranking import Ranking
+from .sorted_list import SortedList, SliceableDeque
 
 __all__ = [
+    'Proxy',
+    'SortedList',
+    'SliceableDeque',
+    'Ranking',
+    'TwoWayDictionary',
     'typednamedtuple',
     'HashableWrapper',
     'Heap',
