@@ -4,8 +4,9 @@ __all__ = [
 ]
 
 
-class BaseSource(object):
+class BaseSource:
     """Base class for all configuration sources"""
+    __slots__ = ()
 
     def provide(self) -> dict:
         """
@@ -23,6 +24,7 @@ class StaticSource(BaseSource):
     """
     A static piece of configuration. Returns exactly what is passed
     """
+    __slots__ = ('config', )
 
     def __init__(self, config: dict):
         self.config = config
