@@ -5,10 +5,11 @@ from .counter import CounterMetric
 from .linkfail import LinkfailMetric
 from .empty import EmptyMetric
 from .histogram import HistogramMetric
+from .callable import CallableMetric
 from .summary import QuantileMetric, SummaryMetric
 from .registry import register_metric, METRIC_NAMES_TO_CLASSES
 
 __all__ = ['Metric', 'LeafMetric', 'EmbeddedSubmetrics', 'RUNTIME', 'DEBUG', 'INHERIT',
            'DISABLED', 'ClicksPerTimeUnitMetric', 'IntegerMetric', 'FloatMetric',
            'QuantileMetric', 'register_metric', 'METRIC_NAMES_TO_CLASSES', 'SummaryMetric',
-           'HistogramMetric', 'EmptyMetric', 'LinkfailMetric']
+           'HistogramMetric', 'EmptyMetric', 'LinkfailMetric', 'CallableMetric']
