@@ -1,9 +1,7 @@
-import logging
 from .base import EmbeddedSubmetrics
 from .measurable_mixin import MeasurableMixin
 from ..data import MetricData, MetricDataCollection
 from .registry import register_metric
-logger = logging.getLogger(__name__)
 
 
 @register_metric
